@@ -376,9 +376,10 @@ class DXF(DXFBase):
         self._repo_path = (repo + '/') if repo else ''
 
     def _request(self, method, path, **kwargs):
-        return super(DXF, self)._base_request(method,
-                                              self._repo_path + path,
-                                              **kwargs)
+        return super(DXF, self)._base_request(
+            method,
+            urlparse.urljoin(self._repo_path, path),
+            **kwargs)
 
     def push_blob(self,
                   filename=None,
