@@ -203,4 +203,4 @@ def doit(args, environ):
         raise
 
 def main():
-    exit(doit(sys.argv[1:], os.environ))
+    sys.exit(doit(sys.argv[1:], os.environ))
